==> zio-aws-apigatewayv2_2.12-5.17.130.3-sources.jar: zio/aws/apigatewayv2/model/DeleteCorsConfigurationRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteCorsConfigurationRequest(apiId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteCorsConfigurationRequest = {
    import DeleteCorsConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteCorsConfigurationRequest
      .builder()
      .apiId(__string.unwrap(apiId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest
      .wrap(buildAwsValue())
}
object DeleteCorsConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteCorsConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest =
      zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest(apiId)
    def apiId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteCorsConfigurationRequest
  ) extends zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest.ReadOnly {
    override val apiId: __string =
      zio.aws.apigatewayv2.model.primitives.__string(impl.apiId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteCorsConfigurationRequest
  ): zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-apigatewayv2_2.12-5.17.267.7-sources.jar: zio/aws/apigatewayv2/model/DeleteCorsConfigurationRequest.scala <==
package zio.aws.apigatewayv2.model
import zio.ZIO
import zio.aws.apigatewayv2.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DeleteCorsConfigurationRequest(apiId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.apigatewayv2.model.DeleteCorsConfigurationRequest = {
    import DeleteCorsConfigurationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.apigatewayv2.model.DeleteCorsConfigurationRequest
      .builder()
      .apiId(apiId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest.ReadOnly =
    zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest
      .wrap(buildAwsValue())
}
object DeleteCorsConfigurationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.apigatewayv2.model.DeleteCorsConfigurationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest =
      zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest(apiId)
    def apiId: __string
    def getApiId: ZIO[Any, Nothing, __string] = ZIO.succeed(apiId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteCorsConfigurationRequest
  ) extends zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest.ReadOnly {
    override val apiId: __string = impl.apiId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.apigatewayv2.model.DeleteCorsConfigurationRequest
  ): zio.aws.apigatewayv2.model.DeleteCorsConfigurationRequest.ReadOnly =
    new Wrapper(impl)
}
